@@ -2,6 +2,7 @@
 # created by Tobias Powalowski <tpowa@archlinux.org>
 . /etc/archboot/defaults
 _CACHEDIR="${1}/var/cache/pacman/pkg"
+_XORG="${_X_PACKAGES} ${_XFCE_PACKAGES}"
 
 _usage () {
     echo "CREATE ARCHBOOT CONTAINER"
@@ -132,10 +133,10 @@ _install_base_packages() {
 }
 
 _install_archboot() {
-    echo "Downloading ${_X_PACKAGES} to ${1} ..."
+    echo "Downloading ${_XORG} to ${1} ..."
     [[ -d "${1}"/blankdb ]] || mkdir "${1}"/blankdb
     #shellcheck disable=SC2086
-    pacman --root "${1}" -Syw --dbpath "${1}"/blankdb ${_X_PACKAGES} --config "${_PACMAN_CONF}" --ignore systemd-resolvconf --cachedir "${_CACHEDIR}" --noconfirm >/dev/null 2>&1
+    pacman --root "${1}" -Syw --dbpath "${1}"/blankdb ${_XORG} --config "${_PACMAN_CONF}" --ignore systemd-resolvconf --cachedir "${_CACHEDIR}" --noconfirm >/dev/null 2>&1
     echo "Installing ${_ARCHBOOT} to ${1} ..."
     #shellcheck disable=SC2086
     pacman --root "${1}" -Sy ${_ARCHBOOT} --config "${_PACMAN_CONF}" --ignore systemd-resolvconf --noconfirm --cachedir "${_CACHEDIR}" >/dev/null 2>&1
@@ -158,9 +159,9 @@ _aarch64_install_archboot() {
     if [[ -e "${1}/$(basename "${_PACMAN_CONF}")"  ]]; then
         _PACMAN_CONF=$(basename "${_PACMAN_CONF}")
     fi
-    echo "Downloading ${_ARCHBOOT} ${_X_PACKAGES} to ${1} ..."
+    echo "Downloading ${_ARCHBOOT} ${_XORG} to ${1} ..."
     [[ -d "${1}"/blankdb ]] || mkdir "${1}"/blankdb
-    systemd-nspawn -q -D "${1}" /bin/bash -c "pacman -Syw --dbpath /blankdb ${_ARCHBOOT} ${_X_PACKAGES} --config ${_PACMAN_CONF} --ignore systemd-resolvconf --noconfirm" >/dev/null 2>&1
+    systemd-nspawn -q -D "${1}" /bin/bash -c "pacman -Syw --dbpath /blankdb ${_ARCHBOOT} ${_XORG} --config ${_PACMAN_CONF} --ignore systemd-resolvconf --noconfirm" >/dev/null 2>&1
     echo "Installing ${_ARCHBOOT} to ${1} ..."
     systemd-nspawn -q -D "${1}" /bin/bash -c "pacman -Sy ${_ARCHBOOT} --config ${_PACMAN_CONF} --ignore systemd-resolvconf --noconfirm" >/dev/null 2>&1
 }
