@@ -25,14 +25,16 @@ usage () {
         echo -e " \033[1m-u\033[0m               Update scripts: setup, quickinst, tz, km and helpers."
         echo -e ""
     fi
+    if [[ "$(grep -w MemTotal /proc/meminfo | cut -d ':' -f2 | sed -e 's# ##g' -e 's#kB$##g')" -gt 3400000 &&\
+    -e /usr/bin/setup && ! -e /var/cache/pacman/pkg/archboot.db ]]; then
+            echo -e " \033[1m-launch-gnome\033[0m    Launch Gnome desktop with VNC sharing enabled."
+            echo -e " \033[1m-launch-kde\033[0m      Launch KDE Plasma desktop with VNC sharing enabled."
+    fi
     if [[ "$(grep -w MemTotal /proc/meminfo | cut -d ':' -f2 | sed -e 's# ##g' -e 's#kB$##g')" -gt 2500000 &&\
     -e /usr/bin/setup ]]; then
             echo -e " \033[1m-launch-xfce\033[0m     Launch XFCE desktop with VNC sharing enabled."
             echo ""
-    fi
-    if [[ "$(grep -w MemTotal /proc/meminfo | cut -d ':' -f2 | sed -e 's# ##g' -e 's#kB$##g')" -gt 3400000 &&\
-    -e /usr/bin/setup && ! -e /var/cache/pacman/pkg/archboot.db ]]; then
-            echo -e " \033[1m-launch-kde\033[0m      Launch KDE Plasma desktop with VNC sharing enabled."
+            echo -e " \033[1m-custom-xorg\033[0m     Install custom X environment."
             echo ""
     fi
     if [[ "$(grep -w MemTotal /proc/meminfo | cut -d ':' -f2 | sed -e 's# ##g' -e 's#kB$##g')" -gt 3900000 &&\
@@ -86,7 +88,7 @@ _download_latest() {
         for i in ${BINS}; do
             [[ -e "${_BIN}/${i}" ]] && wget -q "${_SOURCE}${_BIN}/archboot-${i}.sh?inline=false" -O "${_BIN}/${i}"
         done
-        LIBS="common.sh container.sh release.sh iso.sh update-installer.sh xfce.sh kde.sh login.sh"
+        LIBS="common.sh container.sh release.sh iso.sh update-installer.sh xfce.sh gnome.sh kde.sh login.sh"
         for i in ${LIBS}; do
             wget -q "${_SOURCE}${_LIB}/${i}?inline=false" -O "${_LIB}/${i}"
         done
@@ -279,7 +281,7 @@ _kexec () {
 }
 
 _cleanup_install() {
-    rm -rf /usr/share/{man,info,doc,gtk-doc,ibus,perl5}
+    rm -rf /usr/share/{man,help,gir-1.0,info,doc,gtk-doc,ibus,perl5}
     rm -rf /usr/include
     rm -rf /usr/lib/libgo.*
 }
@@ -334,10 +336,15 @@ _prepare_x() {
     echo "Removing not used icons ..."
     rm -rf /usr/share/icons/breeze-dark
     echo "Recreating C.UTF-8 locale ..."
-    sed -i -e 's:#C.UTF-8 UTF-8:C.UTF-8 UTF-8:g' "${1}/etc/locale.gen"
+    sed -i -e 's:#C.UTF-8 UTF-8:C.UTF-8 UTF-8:g' "/etc/locale.gen"
     locale-gen >/dev/null 2>&1
     echo "Cleanup locale and i18n ..."
     rm -rf /usr/share/{locale,i18n}
+    # needed for environments which check disk space
+    if ! mountpoint /root; then
+        echo "Mount tmpfs on /root"
+        mount -t tmpfs tmpfs /root
+    fi
 }
 
 _chromium_flags() {
